| camera | R Documentation |
Defines a camera for rendering by specifying the eye position, look-at center, up vector, projection type, and field of view.
camera(
eye,
center,
up = c(0, 1, 0),
projection = c("perspective", "orthographic"),
fov = 45
)
eye |
Numeric vector of length 3: camera position. |
center |
Numeric vector of length 3: point the camera looks at. |
up |
Numeric vector of length 3: camera up direction. |
projection |
Projection type: |
fov |
Field of view in degrees (perspective only). |
A camera list suitable for render_mesh() or
render_scene().
cam <- camera(eye = c(0, 0, 5), center = c(0, 0, 0))
cam$eye
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.