| camera_orbit | R Documentation |
Rotates a camera's eye position and up vector around its center by a given angle about a rotation axis. Useful for generating turntable-style frame sequences.
camera_orbit(camera, axis = c(0, 0, 1), angle_degrees)
camera |
A camera list from |
axis |
Rotation axis as a length-3 vector. Default |
angle_degrees |
Rotation angle in degrees. |
A camera list with S3 class "scimesh_camera".
mesh <- generate_torus(c(0, 0, 0))
cam <- camera_auto(mesh, direction = c(1, 1, 1))
cam2 <- camera_orbit(cam, axis = c(0, 0, 1), angle_degrees = 90)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.