| generate_pyramid | R Documentation |
Creates a pyramid with a square base centred at base_center
in the XZ plane, with the apex above it along Y.
generate_pyramid(
base_center,
apex,
half_width = 1,
color = c(0.7, 0.7, 0.7, 1)
)
base_center |
Length-3 vector: centre of the square base. |
apex |
Length-3 vector: position of the tip. |
half_width |
Half-width of the square base. |
color |
Length-4 RGBA colour. |
A mesh descriptor list.
mesh <- generate_pyramid(c(0, 0, 0), c(0, 2, 0), half_width = 1)
mesh$vertices
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.