| image_crop_to_content | R Documentation |
Removes background-coloured margin from the specified edges of the image. The first non-background pixel found on each edge defines the crop boundary.
image_crop_to_content(image, direction, background)
image |
An image list. |
direction |
One of |
background |
Numeric vector of length 4 with RGBA values in
|
A new image list with cropped dimensions.
cube <- generate_cuboid(c(0, 0, 0), c(1, 1, 1))
img <- render_mesh(cube$vertices, cube$triangles,
options = render_options(background_color = c(0, 0, 0, 0)))
img <- image_crop_to_content(img, "all", c(0, 0, 0, 0))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.